"""Module providing a serializer for YAML cassette_data.

:author: Louis Taylor
:maintainer: Louis Taylor
"""

import os

import yaml
from betamax.serializers import BaseSerializer


class YAMLSerializer(BaseSerializer):
    name = 'yaml11'

    @staticmethod
    def generate_cassette_name(cassette_library_dir, cassette_name):
        return os.path.join(cassette_library_dir,
                            '{0}.{1}'.format(cassette_name, 'yml'))

    def serialize(self, cassette_data):
        return yaml.dump(cassette_data)

    def deserialize(self, cassette_data):
        try:
            deserialized_data = yaml.load(cassette_data) or {}
        except yaml.YAMLError:
            deserialized_data = {}

        return deserialized_data



"""
betamax_matchers
================

See https://betamax.readthedocs.org/ for documentation.

:copyright: (c) 2015 by Ian Cordasco
:license: Apache 2.0, see LICENSE for more details

"""

__author__ = 'Ian Stapleton Cordasco'
__copyright__ = 'Copyright 2019 Ian Stapleton Cordasco'
__license__ = 'Apache 2.0'
__title__ = 'betamax_serializers'
__version__ = '0.2.1'
__version_info__ = tuple(int(i) for i in __version__.split('.'))



"""Module providing a pretty-printer for JSON cassette_data.

:author: Jeremy Thurgood
:maintainer: Ian Cordasco
"""
import json

from betamax.serializers import JSONSerializer


class PrettyJSONSerializer(JSONSerializer):
    name = 'prettyjson'

    def serialize(self, cassette_data):
        return json.dumps(
            cassette_data,
            sort_keys=True,
            indent=2,
            separators=(',', ': '),
        )
